@@ -728,8 +728,8 @@ TEST(defmodel, evaluator_horizontal_unit_degree) {
 
     constexpr int iQueriedX = 1;
     constexpr int iQueriedY = 3;
-    constexpr double lonOffsetQueriedX = 0.01;
-    constexpr double lonOffsetQueriedXp1 = 0.02;
+    constexpr double longOffsetQueriedX = 0.01;
+    constexpr double longOffsetQueriedXp1 = 0.02;
     constexpr double latOffsetQueriedY = 0.03;
     constexpr double latOffsetQueriedYp1 = 0.04;
     constexpr double zOffsetQueriedXY = 10.;
@@ -740,12 +740,12 @@ TEST(defmodel, evaluator_horizontal_unit_degree) {
     constexpr double gridResY = 0.5;
 
     struct Grid : public GridPrototype {
-        bool getLonLatOffset(int ix, int iy, double &lonOffsetRadian,
-                             double &latOffsetRadian) const {
+        bool getLongLatOffset(int ix, int iy, double &longOffsetRadian,
+                              double &latOffsetRadian) const {
             if (ix == iQueriedX) {
-                lonOffsetRadian = DegToRad(lonOffsetQueriedX);
+                longOffsetRadian = DegToRad(longOffsetQueriedX);
             } else if (ix == iQueriedX + 1) {
-                lonOffsetRadian = DegToRad(lonOffsetQueriedXp1);
+                longOffsetRadian = DegToRad(longOffsetQueriedXp1);
             } else {
                 return false;
             }
@@ -774,9 +774,10 @@ TEST(defmodel, evaluator_horizontal_unit_degree) {
             return true;
         }
 
-        bool getLonLatZOffset(int ix, int iy, double &lonOffsetRadian,
-                              double &latOffsetRadian, double &zOffset) const {
-            return getLonLatOffset(ix, iy, lonOffsetRadian, latOffsetRadian) &&
+        bool getLongLatZOffset(int ix, int iy, double &longOffsetRadian,
+                               double &latOffsetRadian, double &zOffset) const {
+            return getLongLatOffset(ix, iy, longOffsetRadian,
+                                    latOffsetRadian) &&
                    getZOffset(ix, iy, zOffset);
         }
 
@@ -821,7 +822,7 @@ TEST(defmodel, evaluator_horizontal_unit_degree) {
 
     Evaluator<Grid, GridSet, EvaluatorIface> eval(MasterFile::parse(j.dump()),
                                                   iface, 1, 1);
-    double newLon;
+    double newLong;
     double newLat;
     double newZ;
     constexpr double tValid = 2018;
@@ -830,11 +831,12 @@ TEST(defmodel, evaluator_horizontal_unit_degree) {
 
     // Query on exact grid intersection
     {
-        const double lon = gridMinX + iQueriedX * gridResX;
+        const double longitude = gridMinX + iQueriedX * gridResX;
         const double lat = gridMinY + iQueriedY * gridResY;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 tValid, newLon, newLat, newZ));
-        EXPECT_NEAR(RadToDeg(newLon), lon + tFactor * lonOffsetQueriedX, EPS);
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, tValid, newLong, newLat, newZ));
+        EXPECT_NEAR(RadToDeg(newLong), longitude + tFactor * longOffsetQueriedX,
+                    EPS);
         EXPECT_NEAR(RadToDeg(newLat), lat + tFactor * latOffsetQueriedY, EPS);
         EXPECT_EQ(newZ, zVal);
     }
@@ -843,15 +845,16 @@ TEST(defmodel, evaluator_horizontal_unit_degree) {
     {
         constexpr double alphaX = 0.25;
         constexpr double alphaY = 0.125;
-        const double lon = gridMinX + iQueriedX * gridResX + alphaX * gridResX;
+        const double longitude =
+            gridMinX + iQueriedX * gridResX + alphaX * gridResX;
         const double lat = gridMinY + iQueriedY * gridResY + alphaY * gridResY;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 tValid, newLon, newLat, newZ));
-        EXPECT_NEAR(
-            RadToDeg(newLon),
-            lon + tFactor * (lonOffsetQueriedX + alphaX * (lonOffsetQueriedXp1 -
-                                                           lonOffsetQueriedX)),
-            EPS);
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, tValid, newLong, newLat, newZ));
+        EXPECT_NEAR(RadToDeg(newLong),
+                    longitude + tFactor * (longOffsetQueriedX +
+                                           alphaX * (longOffsetQueriedXp1 -
+                                                     longOffsetQueriedX)),
+                    EPS);
         EXPECT_NEAR(
             RadToDeg(newLat),
             lat + tFactor * (latOffsetQueriedY + alphaY * (latOffsetQueriedYp1 -
@@ -862,103 +865,103 @@ TEST(defmodel, evaluator_horizontal_unit_degree) {
 
     // Longitude < model min
     {
-        const double lon = modelMinX - 1e-1;
+        const double longitude = modelMinX - 1e-1;
         const double lat = gridMinY + iQueriedY * gridResY;
-        EXPECT_FALSE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                  tValid, newLon, newLat, newZ));
+        EXPECT_FALSE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                  zVal, tValid, newLong, newLat, newZ));
     }
 
     // Longitude > model max
     {
-        const double lon = modelMaxX + 1e-1;
+        const double longitude = modelMaxX + 1e-1;
         const double lat = gridMinY + iQueriedY * gridResY;
-        EXPECT_FALSE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                  tValid, newLon, newLat, newZ));
+        EXPECT_FALSE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                  zVal, tValid, newLong, newLat, newZ));
     }
 
     // Latitude < model min
     {
-        const double lon = gridMinX + iQueriedX * gridResX;
+        const double longitude = gridMinX + iQueriedX * gridResX;
         const double lat = modelMinY - 1e-1;
-        EXPECT_FALSE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                  tValid, newLon, newLat, newZ));
+        EXPECT_FALSE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                  zVal, tValid, newLong, newLat, newZ));
     }
 
     // Latitude > model max
     {
-        const double lon = gridMinX + iQueriedX * gridResX;
+        const double longitude = gridMinX + iQueriedX * gridResX;
         const double lat = modelMaxY + 1e-1;
-        EXPECT_FALSE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                  tValid, newLon, newLat, newZ));
+        EXPECT_FALSE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                  zVal, tValid, newLong, newLat, newZ));
     }
 
     // Before timeExtent.first
     {
-        const double lon = gridMinX + iQueriedX * gridResX;
+        const double longitude = gridMinX + iQueriedX * gridResX;
         const double lat = gridMinY + iQueriedY * gridResY;
-        EXPECT_FALSE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                  1000, newLon, newLat, newZ));
+        EXPECT_FALSE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                  zVal, 1000, newLong, newLat, newZ));
     }
 
     // After timeExtent.last
     {
-        const double lon = gridMinX + iQueriedX * gridResX;
+        const double longitude = gridMinX + iQueriedX * gridResX;
         const double lat = gridMinY + iQueriedY * gridResY;
-        EXPECT_FALSE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                  3000, newLon, newLat, newZ));
+        EXPECT_FALSE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                  zVal, 3000, newLong, newLat, newZ));
     }
 
     // Longitude < grid min
     {
-        const double lon = gridMinX - 1e-1;
+        const double longitude = gridMinX - 1e-1;
         const double lat = gridMinY + iQueriedY * gridResY;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 tValid, newLon, newLat, newZ));
-        EXPECT_NEAR(RadToDeg(newLon), lon, EPS);
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, tValid, newLong, newLat, newZ));
+        EXPECT_NEAR(RadToDeg(newLong), longitude, EPS);
         EXPECT_NEAR(RadToDeg(newLat), lat, EPS);
         EXPECT_EQ(newZ, zVal);
     }
 
     // Longitude > grid max
     {
-        const double lon = gridMaxX + 1e-1;
+        const double longitude = gridMaxX + 1e-1;
         const double lat = gridMinY + iQueriedY * gridResY;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 tValid, newLon, newLat, newZ));
-        EXPECT_NEAR(RadToDeg(newLon), lon, EPS);
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, tValid, newLong, newLat, newZ));
+        EXPECT_NEAR(RadToDeg(newLong), longitude, EPS);
         EXPECT_NEAR(RadToDeg(newLat), lat, EPS);
         EXPECT_EQ(newZ, zVal);
     }
 
     // Latitude < grid min
     {
-        const double lon = gridMinX + iQueriedX * gridResX;
+        const double longitude = gridMinX + iQueriedX * gridResX;
         const double lat = gridMinY - 1e-1;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 tValid, newLon, newLat, newZ));
-        EXPECT_NEAR(RadToDeg(newLon), lon, EPS);
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, tValid, newLong, newLat, newZ));
+        EXPECT_NEAR(RadToDeg(newLong), longitude, EPS);
         EXPECT_NEAR(RadToDeg(newLat), lat, EPS);
         EXPECT_EQ(newZ, zVal);
     }
 
     // Latitude > grid max
     {
-        const double lon = gridMinX + iQueriedX * gridResX;
+        const double longitude = gridMinX + iQueriedX * gridResX;
         const double lat = gridMaxY + 1e-1;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 tValid, newLon, newLat, newZ));
-        EXPECT_NEAR(RadToDeg(newLon), lon, EPS);
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, tValid, newLong, newLat, newZ));
+        EXPECT_NEAR(RadToDeg(newLong), longitude, EPS);
         EXPECT_NEAR(RadToDeg(newLat), lat, EPS);
         EXPECT_EQ(newZ, zVal);
     }
 
     // Time function values to zero
     {
-        const double lon = gridMinX + iQueriedX * gridResX;
+        const double longitude = gridMinX + iQueriedX * gridResX;
         const double lat = gridMinY + iQueriedY * gridResY;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 2000, newLon, newLat, newZ));
-        EXPECT_NEAR(RadToDeg(newLon), lon, EPS);
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, 2000, newLong, newLat, newZ));
+        EXPECT_NEAR(RadToDeg(newLong), longitude, EPS);
         EXPECT_NEAR(RadToDeg(newLat), lat, EPS);
         EXPECT_EQ(newZ, zVal);
     }
@@ -971,11 +974,13 @@ TEST(defmodel, evaluator_horizontal_unit_degree) {
     {
         constexpr double alphaX = 0.25;
         constexpr double alphaY = 0.125;
-        const double lon = gridMinX + iQueriedX * gridResX + alphaX * gridResX;
+        const double longitude =
+            gridMinX + iQueriedX * gridResX + alphaX * gridResX;
         const double lat = gridMinY + iQueriedY * gridResY + alphaY * gridResY;
-        EXPECT_TRUE(evalVertical.forward(iface, DegToRad(lon), DegToRad(lat),
-                                         zVal, tValid, newLon, newLat, newZ));
-        EXPECT_NEAR(RadToDeg(newLon), lon, EPS);
+        EXPECT_TRUE(evalVertical.forward(iface, DegToRad(longitude),
+                                         DegToRad(lat), zVal, tValid, newLong,
+                                         newLat, newZ));
+        EXPECT_NEAR(RadToDeg(newLong), longitude, EPS);
         EXPECT_NEAR(RadToDeg(newLat), lat, EPS);
 
         const double zBottom =
@@ -995,15 +1000,16 @@ TEST(defmodel, evaluator_horizontal_unit_degree) {
     {
         constexpr double alphaX = 0.25;
         constexpr double alphaY = 0.125;
-        const double lon = gridMinX + iQueriedX * gridResX + alphaX * gridResX;
+        const double longitude =
+            gridMinX + iQueriedX * gridResX + alphaX * gridResX;
         const double lat = gridMinY + iQueriedY * gridResY + alphaY * gridResY;
-        EXPECT_TRUE(eval3d.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                   tValid, newLon, newLat, newZ));
-        EXPECT_NEAR(
-            RadToDeg(newLon),
-            lon + tFactor * (lonOffsetQueriedX + alphaX * (lonOffsetQueriedXp1 -
-                                                           lonOffsetQueriedX)),
-            EPS);
+        EXPECT_TRUE(eval3d.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                   zVal, tValid, newLong, newLat, newZ));
+        EXPECT_NEAR(RadToDeg(newLong),
+                    longitude + tFactor * (longOffsetQueriedX +
+                                           alphaX * (longOffsetQueriedXp1 -
+                                                     longOffsetQueriedX)),
+                    EPS);
         EXPECT_NEAR(
             RadToDeg(newLat),
             lat + tFactor * (latOffsetQueriedY + alphaY * (latOffsetQueriedYp1 -
@@ -1218,7 +1224,7 @@ TEST(defmodel, evaluator_horizontal_unit_metre) {
     constexpr double zVal = 100;
 
     const struct {
-        double lon;
+        double longitude;
         double lat;
         double expected_de;
         double expected_dn;
@@ -1256,62 +1262,63 @@ TEST(defmodel, evaluator_horizontal_unit_metre) {
         Evaluator<Grid, GridSet, EvaluatorIface> eval(
             MasterFile::parse(j.dump()), iface, a, b);
 
-        const double lon = testPoint.lon;
+        const double longitude = testPoint.longitude;
         const double lat = testPoint.lat;
-        double newLon;
+        double newLong;
         double newLat;
         double newZ;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 tValid, newLon, newLat, newZ))
-            << lon << " " << lat << " " << testPoint.displacement_type
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, tValid, newLong, newLat, newZ))
+            << longitude << " " << lat << " " << testPoint.displacement_type
             << testPoint.interpolation_method;
         EXPECT_NEAR(newZ - zVal, tFactor * testPoint.expected_dz, 1e-8)
-            << lon << " " << lat << " " << testPoint.displacement_type
+            << longitude << " " << lat << " " << testPoint.displacement_type
             << testPoint.interpolation_method;
 
         double de;
         double dn;
-        DeltaLongLatToEastingNorthing(DegToRad(lat), newLon - DegToRad(lon),
+        DeltaLongLatToEastingNorthing(DegToRad(lat),
+                                      newLong - DegToRad(longitude),
                                       newLat - DegToRad(lat), a, b, de, dn);
         EXPECT_NEAR(de, tFactor * testPoint.expected_de, 1e-8)
-            << lon << " " << lat << " " << testPoint.displacement_type
+            << longitude << " " << lat << " " << testPoint.displacement_type
             << testPoint.interpolation_method;
         EXPECT_NEAR(dn, tFactor * testPoint.expected_dn, 1e-8)
-            << lon << " " << lat << " " << testPoint.displacement_type
+            << longitude << " " << lat << " " << testPoint.displacement_type
             << testPoint.interpolation_method;
 
-        if (lon == gridMinX && lat == gridMinY) {
+        if (longitude == gridMinX && lat == gridMinY) {
             // Redo the exact same test, to test caching
-            double newLon2;
+            double newLong2;
             double newLat2;
             double newZ2;
-            EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                     tValid, newLon2, newLat2, newZ2));
-            EXPECT_EQ(newLon2, newLon);
+            EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                     zVal, tValid, newLong2, newLat2, newZ2));
+            EXPECT_EQ(newLong2, newLong);
             EXPECT_EQ(newLat2, newLat);
             EXPECT_EQ(newZ2, newZ);
 
             // Shift in longitude
-            EXPECT_TRUE(eval.forward(iface, DegToRad(lon - gridResX / 2),
-                                     DegToRad(lat), zVal, tValid, newLon2,
+            EXPECT_TRUE(eval.forward(iface, DegToRad(longitude - gridResX / 2),
+                                     DegToRad(lat), zVal, tValid, newLong2,
                                      newLat2, newZ2));
 
             // Redo test at original position
-            EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                     tValid, newLon2, newLat2, newZ2));
-            EXPECT_EQ(newLon2, newLon);
+            EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                     zVal, tValid, newLong2, newLat2, newZ2));
+            EXPECT_EQ(newLong2, newLong);
             EXPECT_EQ(newLat2, newLat);
             EXPECT_EQ(newZ2, newZ);
 
             // Shift in latitude
-            EXPECT_TRUE(eval.forward(iface, DegToRad(lon),
+            EXPECT_TRUE(eval.forward(iface, DegToRad(longitude),
                                      DegToRad(lat - gridResY / 2), zVal, tValid,
-                                     newLon2, newLat2, newZ2));
+                                     newLong2, newLat2, newZ2));
 
             // Redo test at original position
-            EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                     tValid, newLon2, newLat2, newZ2));
-            EXPECT_EQ(newLon2, newLon);
+            EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                     zVal, tValid, newLong2, newLat2, newZ2));
+            EXPECT_EQ(newLong2, newLong);
             EXPECT_EQ(newLat2, newLat);
             EXPECT_EQ(newZ2, newZ);
         }
@@ -1326,20 +1333,20 @@ TEST(defmodel, evaluator_horizontal_unit_metre) {
         Evaluator<Grid, GridSet, EvaluatorIface> eval(
             MasterFile::parse(j.dump()), iface, a, b);
 
-        const double lon = 165.9;
+        const double longitude = 165.9;
         const double lat = -37.3;
-        double newLon;
+        double newLong;
         double newLat;
         double newZ;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 tValid, newLon, newLat, newZ));
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, tValid, newLong, newLat, newZ));
 
-        double invLon;
+        double invLongitude;
         double invLat;
         double invZ;
-        EXPECT_TRUE(eval.inverse(iface, newLon, newLat, newZ, tValid, invLon,
-                                 invLat, invZ));
-        EXPECT_NEAR(RadToDeg(invLon), lon, 1e-10);
+        EXPECT_TRUE(eval.inverse(iface, newLong, newLat, newZ, tValid,
+                                 invLongitude, invLat, invZ));
+        EXPECT_NEAR(RadToDeg(invLongitude), longitude, 1e-10);
         EXPECT_NEAR(RadToDeg(invLat), lat, 1e-10);
         EXPECT_NEAR(invZ, zVal, 1e-4);
     }
@@ -1353,19 +1360,20 @@ TEST(defmodel, evaluator_horizontal_unit_metre) {
         Evaluator<Grid, GridSet, EvaluatorIface> eval(
             MasterFile::parse(j.dump()), iface, a, b);
 
-        const double lon = gridMinX;
+        const double longitude = gridMinX;
         const double lat = gridMinY;
-        double newLon;
+        double newLong;
         double newLat;
         double newZ;
-        EXPECT_TRUE(eval.forward(iface, DegToRad(lon), DegToRad(lat), zVal,
-                                 tValid, newLon, newLat, newZ));
+        EXPECT_TRUE(eval.forward(iface, DegToRad(longitude), DegToRad(lat),
+                                 zVal, tValid, newLong, newLat, newZ));
 
         double de;
         double dn;
         constexpr double expected_de = 0.40000000948081327;
         constexpr double expected_dn = -0.19999999810542682;
-        DeltaLongLatToEastingNorthing(DegToRad(lat), newLon - DegToRad(lon),
+        DeltaLongLatToEastingNorthing(DegToRad(lat),
+                                      newLong - DegToRad(longitude),
                                       newLat - DegToRad(lat), a, b, de, dn);
         EXPECT_NEAR(de, tFactor * expected_de, 1e-10);
         EXPECT_NEAR(dn, tFactor * expected_dn, 1e-9);
